package com.zipcoder.payment;

import org.junit.Assert;
import org.junit.Test;

public class PaymentPresenterTest {

    Payment paypal = new PayPal(4L, "Tia Mowry", "tia@mowry.com");
    Payment check = new Check(81L, "Abigail Henry", "11432543", "134344551");
    Payment creditCard = new CreditCard(15L, "Danny Tanner", "45454545", 12, 2099);

    @Test
    public void testNoPayment() {
        Payment[] payments = new Payment[0];
        PaymentPresenter presenter = new PaymentPresenter();
        String expected = "";

        String actual = presenter.toString(payments);

        Assert.assertEquals(expected, actual);
    }

    @Test
    public void testPaymentsNoSort() {
        Payment[] payments = {paypal, check, creditCard};
        PaymentPresenter presenter = new PaymentPresenter();
        String expected = "CC Danny Tanner 4545 12/2099\n" +
                "Check Abigail Henry ***4551\n" +
                "PayPal Tia Mowry tia@mowry.com";

        String actual = presenter.toString(payments);

        Assert.assertEquals(expected, actual);
    }

    @Test
    public void testPaymentsSort() {
        Payment[] payments = {creditCard, check, paypal};
        PaymentPresenter presenter = new PaymentPresenter();
        String expected = "CC Danny Tanner 4545 12/2099\n" +
                "Check Abigail Henry ***4551\n" +
                "PayPal Tia Mowry tia@mowry.com";

        String actual = presenter.toString(payments);

        Assert.assertEquals(expected, actual);
    }

    @Test
    public void testNoPaymentByName() {
        Payment[] payments = new Payment[0];
        PaymentPresenter presenter = new PaymentPresenter();
        String expected = "";

        String actual = presenter.toStringByPayerName(payments);

        Assert.assertEquals(expected, actual);
    }

    @Test
    public void testPaymentsByNameNoSort() {
        Payment[] payments = {check, creditCard, paypal};
        PaymentPresenter presenter = new PaymentPresenter();
        String expected = "Check Abigail Henry ***4551\n" +
                "CC Danny Tanner 4545 12/2099\n" +
                "PayPal Tia Mowry tia@mowry.com";

        String actual = presenter.toStringByPayerName(payments);

        Assert.assertEquals(expected, actual);
    }

    @Test
    public void testPaymentsByNameSort() {
        Payment[] payments = {creditCard, check, paypal};
        PaymentPresenter presenter = new PaymentPresenter();
        String expected = "Check Abigail Henry ***4551\n" +
                "CC Danny Tanner 4545 12/2099\n" +
                "PayPal Tia Mowry tia@mowry.com";

        String actual = presenter.toStringByPayerName(payments);

        Assert.assertEquals(expected, actual);
    }

    @Test
    public void testNoPaymentById() {
        Payment[] payments = new Payment[0];
        PaymentPresenter presenter = new PaymentPresenter();
        String expected = "";

        String actual = presenter.toStringById(payments);

        Assert.assertEquals(expected, actual);
    }

    @Test
    public void testPaymentsByIdNoSort() {
        Payment[] payments = {paypal, creditCard, check};
        PaymentPresenter presenter = new PaymentPresenter();
        String expected = "PayPal Tia Mowry tia@mowry.com\n" +
                "CC Danny Tanner 4545 12/2099\n" +
                "Check Abigail Henry ***4551";

        String actual = presenter.toStringById(payments);

        Assert.assertEquals(expected, actual);
    }

    @Test
    public void testPaymentsByIdSort() {
        Payment[] payments = {creditCard, check, paypal};
        PaymentPresenter presenter = new PaymentPresenter();
        String expected = "PayPal Tia Mowry tia@mowry.com\n" +
                "CC Danny Tanner 4545 12/2099\n" +
                "Check Abigail Henry ***4551";

        String actual = presenter.toStringById(payments);

        Assert.assertEquals(expected, actual);
    }

}
